@@ -9,7 +9,9 @@ def main():
     import fbrp.cmd.down
     import fbrp.cmd.list
     import fbrp.cmd.logs
+    import fbrp.cmd.ps
     import fbrp.cmd.up
+    import fbrp.cmd.wait
 
     parser = argparse.ArgumentParser(prog="fbrp")
     parser.add_argument("-v", "--verbose", default=False, action="store_true")
