@@ -1,3 +1,4 @@
+from fbrp import life_cycle
 from fbrp import util
 from fbrp.runtime.base import BaseLauncher, BaseRuntime
 from fbrp.process import ProcDef
@@ -11,6 +12,7 @@ import io
 import json
 import os
 import pwd
+import sys
 import typing
 
 
@@ -32,6 +34,7 @@ class Launcher(BaseLauncher):
         self.kwargs = kwargs
 
     async def run(self):
+        life_cycle.set_state(self.name, life_cycle.State.STARTING)
         docker = aiodocker.Docker()
 
         container = f"fbrp_{self.name}"
@@ -87,6 +90,7 @@ class Launcher(BaseLauncher):
 
         proc_info = await self.proc.show()
         self.proc_pid = proc_info["State"]["Pid"]
+        life_cycle.set_state(self.name, life_cycle.State.STARTED)
 
         async def log_pipe(logger, pipe):
             async for line in pipe:
@@ -97,30 +101,22 @@ class Launcher(BaseLauncher):
             log_pipe(util.stderr_logger(), self.proc.log(stderr=True, follow=True)),
             self.log_psutil(),
             self.death_handler(),
-            self.command_handler(),
+            self.down_watcher(self.handle_down),
         )
+        await docker.close()
 
     def get_pid(self):
         return self.proc_pid
 
     async def death_handler(self):
-        await self.proc.wait()
+        result = await self.proc.wait()
+        life_cycle.set_state(
+            self.name, life_cycle.State.STOPPED, return_code=result["StatusCode"]
+        )
         # TODO(lshamis): Restart policy goes here.
 
-    async def command_handler(self):
-        async for pkt in a0.aio_sub(
-            f"_/control/{self.name}", a0.INIT_AWAIT_NEW, a0.ITER_NEXT
-        ):
-            try:
-                cmd = json.loads(pkt.payload)
-                handle = {
-                    "down": self.handle_down,
-                }[cmd["action"]]
-                await handle(**cmd.get("kwargs", {}))
-            except:
-                pass
-
     async def handle_down(self):
+        life_cycle.set_state(self.name, life_cycle.State.STOPPING)
         await self.proc.stop()
         with contextlib.suppress(asyncio.TimeoutError):
             await self.proc.wait(timeout=3.0)
@@ -171,6 +167,13 @@ class Docker(BaseRuntime):
 
         nfs_mounts = []
         for host, container in mount_map.items():
+            try:
+                os.makedirs(host)
+            except FileExistsError:
+                pass
+            except FileNotFoundError:
+                pass
+
             nfs_root = util.nfs_root(host)
             if nfs_root and nfs_root != host:
                 nfs_mounts.append(
